# Import needed function from setuptools
from setuptools import setup
with open("README.md", "r") as fh:
    long_description = fh.read()

# Create proper setup to be used by pip
setup(name='kmersfasta',
      version='0.0.2',
      python_requires='>3.6.0',
      long_description=long_description,
      long_description_content_type="text/markdown",
      description='Display and count k-mers from the fasta file',
      author='Roshan Shrestha',
      packages=['kmersfasta'],
      install_requires=['biopython'])




from collections import Counter
from itertools import product
from Bio import Entrez
def kmers_from_file(file):
    b = True
    while b:
        try:
            with open(file) as f:
                f.readline()
                ly = []
                for i in f.readlines():
                    ly.append(i)
            b = False
        except:
            print('Enter the correct filename: ')
    fasta_string = ''.join([i.strip() for i in ly])
    k = int(input('Enter the value of k: '))
    counts = Counter(fasta_string[i:i+k] for i in range(0,len(fasta_string)) if len(fasta_string[i:i+k])==k)
    for k_mer in (''.join(t) for t in product('ACGT', repeat=k)):
        print(f"count of {k_mer} is {counts[k_mer]}")

def kmers_from_ncbi(email):
    Entrez.email = email
    file = input('Enter the ncbi accession number: ')
    k = int(input('Enter the value of k: '))
    handle = Entrez.efetch(db = 'nucleotide', id = file,rettype="fasta", retmode="text")
    record = handle.read()
    fasta_string = ''.join(record.split('\n')[1:])
    counts = Counter(''.join(t) for t in zip(*[iter(fasta_string)]*k))
    for k_mer in (''.join(t) for t in product('ACGT', repeat=k)):
        print(f"count of {k_mer} is {counts[k_mer]}")
